<?php
/*
Plugin Name: Etsy Sidebar Widget
Plugin URI: None
Description: Etsy Sidebar Widget. This widget it based on the GoogleTalk Widget by Alax.Info.
Version: 1.0
Author: Troy Schulz
Author URI: http://www.padp.com
*/

/*
ACTIVATE THIS PLUG AND THEN ADD THE WIDGET TO YOUR SIDEBAR FROM THE WIDGETS PAGE.

First thing to do after that is go to your Etsy site and login.
Step 1: Click on Your Etsy in the navbar on the very top of the site.
Step 2: Look in the bottom left of the sidebar, click on Etsy Mini.
Step 3: Choose whether you want to display items from your shop or from your favorites.
Step 4: Decide what size images you would like displayed on your website.
Step 5: Select the layout you would like from the drop down menu. 
		Suddenly, a preview of your desired layout and products will appear below.  
		Right below the preview you will see a few lines of code. 
		There are two formats, one is JavaScript, the other in Flash. 
		I find the Flash code works better.
Step 6: Click in the box to highlight and then copy this code.
Step 7: In your admin, go to the Widgets page where you have added your new widget and click EDIT.
Step 8: Give it a title and paste this code into the box at the bottom.
Step 9: Click Done. Click Save Changes.

Now preview your site.

*/

class AddEtsyWidget 
{
  // static init callback
  function init() 
  {
    // Check for the required plugin functions. This will prevent fatal
    // errors occurring when you deactivate the dynamic-sidebar plugin.
    if(!function_exists('register_sidebar_widget'))
      return;
    $widget = new AddEtsyWidget();
    
    // This registers our widget so it appears with the other available
    // widgets and can be dragged and dropped into any active sidebars.
    register_sidebar_widget('My Etsy', array($widget, 'display'));

    // This registers our optional widget control form.
    register_widget_control('My Etsy', array($widget, 'control'), 125, 155);
  }

  // This is the function outputs the AddThis Subscribe button
  function display($args) 
  {
    // $args is an array of strings that help widgets to conform to
    // the active theme: before_widget, before_title, after_widget,
    // and after_title are the array keys. Default tags: li and h2.
    extract($args);

    $options = get_option('widget_etsy');
    $title = $options['title'];
    $iframetext = $options['iframetext'];

    // These lines generate our output.
    echo $before_widget;
    if($title)
      echo $before_title . $title . $after_title;
    echo '<div style="margin: 2px; margin-top: 6px; " class="etsy">' . $iframetext . '</div>';
    echo $after_widget;
  }

  // This is the function that outputs the control form
  function control() 
  {
    // Get our options and see if we're handling a form submission.
    $options = get_option('widget_etsy');
    if(!is_array($options))
      $options = array('title' => 'My Etsy', 'iframetext' => '');

    if($_POST['etsy-submit']) 
    {
      // Remember to sanitize and format use input appropriately (strip_tags, stripslashes)
      $options['title'] = strip_tags(stripslashes($_POST['etsy-title']));
      $options['iframetext'] = stripslashes($_POST['etsy-iframetext']);
      update_option('widget_etsy', $options);
    }

    // Be sure you format your options to be valid HTML attributes.
    $title = htmlspecialchars($options['title'], ENT_QUOTES);
    $iframetext = htmlspecialchars($options['iframetext'], ENT_QUOTES);

    // Here is our little form segment. Notice that we don't need a
    // complete form. This will be embedded into the existing form.
    echo '<p style="text-align: right"><label for="etsy-title">' . __('Title:&nbsp;') . '<input style="width: 125px" id="etsy-title" name="etsy-title" type="text" value="' . __("$title") . '" /></label></p>';
    echo '<p style="text-align: right"><label for="etsy-iframetext">' . __('Text:&nbsp;') . '<textarea style="width: 125px" id="etsy-iframetext" name="etsy-iframetext">' . __("$iframetext") . '</textarea></label></p>';
    echo '<input type="hidden" id="etsy-submit" name="etsy-submit" value="1" />';
  }
}

// Run our code later in case this loads prior to any required plugins.
add_action('widgets_init', array('AddEtsyWidget', 'init'));

?>
